@@ -15,7 +15,7 @@
    limitations under the License.
 """
 
-import csv
+from csv import reader
 from nspywrapper import nsRequests
 from time import time
 from random import choice
@@ -40,7 +40,7 @@ def answer_issues():
     auth = []
     try:
         with open("./puppets.csv") as csv_file:
-            csv_reader = csv.reader(csv_file)
+            csv_reader = reader(csv_file)
             for row in csv_reader:
                 auth.append([row[0].replace(" ", "_"), row[1]])
     except (OSError, FileNotFoundError, IOError) as err:
@@ -50,7 +50,7 @@ def answer_issues():
     priorities = []
     try:
         with open("./priorities.csv") as csv_file:
-            csv_reader = csv.reader(csv_file)
+            csv_reader = reader(csv_file)
             for row in csv_reader:
                 priorities.append([row[0], row[1]])
     except (OSError, FileNotFoundError, IOError) as err:
@@ -84,11 +84,12 @@ def answer_issues():
                     chosen_op = choice(issue_options)
 
                 if chosen_op != "!":
-                    out_url = f"https://www.nationstates.net/page=enact_dilemma/choice-{chosen_op}=1/dilemma={issue_id}/" \
-                              f"asnation={credentials[0]}/container={credentials[0]}/nation={credentials[0]}/\n"
+                    out_url = f"https://www.nationstates.net/container={credentials[0]}/page=enact_dilemma/" \
+                              f"choice-{chosen_op}=1/dilemma={issue_id}/template-overall=none/" \
+                              f"nation={credentials[0]}/asnation={credentials[0]}"
                 else:
-                    out_url = f"https://www.nationstates.net/page=show_dilemma/dilemma={issue_id}/" \
-                              f"asnation={credentials[0]}/container={credentials[0]}/nation={credentials[0]}/\n"
+                    out_url = f"https://www.nationstates.net/container={credentials[0]}/page=show_dilemma/" \
+                              f"dilemma={issue_id}/nation={credentials[0]}/asnation={credentials[0]}"
 
                 with open("./output.txt", "a+") as file:
                     file.write(out_url)
@@ -98,3 +99,69 @@ def answer_issues():
     e_time = time()
     r_time = e_time-s_time
     print("\nruntime: "+str(r_time)[:5]+" secs")
+
+
+def generate_links():
+    with open('./output.txt') as f:
+        link_list = f.read().split('\n')
+
+    link_list = ['<tr><td><p><a target="_blank" href="'+lnk+'">Link to Issue</a></p></td></tr>\n' for lnk in link_list]
+
+    links = """
+    <html>
+    <head>
+    <style>
+    td.createcol p {
+        padding-left: 10em;
+    }
+
+    a {
+        text-decoration: none;
+        color: black;
+    }
+
+    a:visited {
+        color: grey;
+    }
+
+    table {
+        border-collapse: collapse;
+        display: table-cell;
+        max-width: 100%;
+        background-color: lightgrey;
+    }
+
+    td p {
+        padding: 0.5em;
+    }
+
+    </style>
+    </head>
+    <body>
+    <table>
+    """
+
+    for link in link_list:
+        links = links + link
+
+    links = links + """<tr><td><p><a target="_blank" href="#">Done!</a></p></td></tr>
+    </table>
+    <script>
+    document.querySelectorAll("td").forEach(function(el) {
+        el.addEventListener("click", function() {
+            let myidx = 0;
+            const row = el.parentNode;
+            let child = el;
+            while((child = child.previousElementSibling) != null) {
+                myidx++;
+            }
+            row.nextElementSibling.childNodes[myidx].querySelector("p > a").focus();
+            row.parentNode.removeChild(row);
+        });
+    });
+    </script>
+    </body>
+    """
+
+    with open("./output.html", "w+") as f:
+        f.write(links)
